@@ -1108,6 +1108,12 @@ int brl_xml_init (char* DeviceName, int Port, BRL_XML_INPUT_PROC InputCallbackPr
 	if (!brl_xml_initialized)
 	{
 
+		/* initialize the low level Braille stuff */
+	
+		brl_init();		
+		if (!brl_open_device (DeviceName, Port, BrailleEvents) )
+		    return FALSE;
+		
 		XMLClientCallback = InputCallbackProc;
 		xmlInitParser();
 	
@@ -1127,10 +1133,6 @@ int brl_xml_init (char* DeviceName, int Port, BRL_XML_INPUT_PROC InputCallbackPr
 		brl_ctx->error = brl_error;
 		brl_ctx->fatalError = brl_fatalError;
 	
-		/* initialize the low level Braille stuff */
-	
-		brl_init();		
-		rv = brl_open_device (DeviceName, Port, BrailleEvents);
 	
 		brl_xml_initialized = TRUE;
 	
