@@ -167,7 +167,7 @@ brlmon_gconf_client_init (void)
     if (brlmon_client == NULL) 
     {
 	sru_warning ("brlmon:Failed to init GConf client:\n");
-	sru_warning ("Recomanded to delete ~/.gconf/gnopernicus directories");
+	sru_warning ("Recommended to delete ~/.gconf/gnopernicus directories");
 	return FALSE;
     }
 	             
@@ -177,7 +177,7 @@ brlmon_gconf_client_init (void)
     if (error != NULL)
     {
 	sru_warning ("brlmon:Failed to add directory:\n");
-	sru_warning ("Recomanded to delete ~/.gconf/apps/gnopernicus directories");
+	sru_warning ("Recommended to delete ~/.gconf/apps/gnopernicus directories");
 	g_error_free (error);
 	error = NULL;
 	brlmon_client = NULL;
@@ -223,7 +223,7 @@ brlmon_set_int (gint val, const gchar *key)
     if (error != NULL)
     {
 	sru_warning ("brlmon:Failed to set value:%d\n",val);
-	sru_warning ("Recomanded to delete ~/.gconf/apps/gnopernicus directories");
+	sru_warning ("Recommended to delete ~/.gconf/apps/gnopernicus directories");
 	g_error_free (error);
 	error = NULL;
     }
@@ -258,7 +258,7 @@ brlmon_get_int_with_default (const gchar *key, gint def)
         else
 	{
     	    sru_warning ("brlmon:Invalid type of key %s\n",key);
-	    sru_warning ("Recomanded to delete ~/.gconf/apps/gnopernicus directories");
+	    sru_warning ("Recommended to delete ~/.gconf/apps/gnopernicus directories");
 		
 	    if (!brlmon_set_int (ret_val,key))
 	        sru_warning ("brlmon:Failed to set sring value:%d",ret_val);
@@ -275,7 +275,7 @@ brlmon_get_int_with_default (const gchar *key, gint def)
 	if (error != NULL)
 	{
 	    sru_warning ("brlmon:Failed to get value %s\n",key);
-	    sru_warning ("Recomanded to delete ~/.gconf/apps/gnopernicus directories");
+	    sru_warning ("Recommended to delete ~/.gconf/apps/gnopernicus directories");
 	}
 	    
 	if (!brlmon_set_int (def,key))
@@ -307,7 +307,7 @@ brlmon_set_string (const gchar *val, const gchar *key)
     if (error != NULL)
     {
 	    sru_warning ("brlmon:Failed to set value:%s\n",val);
-	    sru_warning ("Recomanded to delete ~/.gconf/apps/gnopernicus directories");
+	    sru_warning ("Recommended to delete ~/.gconf/apps/gnopernicus directories");
 	    g_error_free (error);
 	    error = NULL;
     }
@@ -333,7 +333,7 @@ brlmon_get_string_with_default (const gchar *key, gchar *def)
     if (error)
     {
 	sru_warning("brlmon:Failed return string value %s\n",key);
-	sru_warning("Recomanded to delete ~/.gconf/apps/gnopernicus directories");
+	sru_warning("Recommended to delete ~/.gconf/apps/gnopernicus directories");
 	g_error_free(error);
 	error = NULL;
 	if (!brlmon_set_string (def,key))
@@ -959,9 +959,9 @@ brlmon_create_item (gint line, gint col)
 	gtk_widget_ref (cell[panel_pos]);
 	gtk_text_view_set_editable (GTK_TEXT_VIEW(cell[panel_pos]),FALSE);
 	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(cell[panel_pos]),FALSE);
-	gtk_text_view_set_pixels_above_lines (GTK_TEXT_VIEW (cell[panel_pos]), 4);
-	gtk_text_view_set_pixels_below_lines (GTK_TEXT_VIEW (cell[panel_pos]), 2);
-	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (cell[panel_pos]), 2);
+/*	gtk_text_view_set_pixels_above_lines (GTK_TEXT_VIEW (cell[panel_pos]), 1);
+	gtk_text_view_set_pixels_below_lines (GTK_TEXT_VIEW (cell[panel_pos]), 1);
+*/	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (cell[panel_pos]), 2);
 	gtk_text_view_set_right_margin (GTK_TEXT_VIEW (cell[panel_pos]), 2);
 	gtk_object_set_data_full (GTK_OBJECT (hbox1), "c", cell[panel_pos],
                         		(GtkDestroyNotify) gtk_widget_unref);
