@@ -155,7 +155,7 @@ static gint 	gn_semid;
  * sr_pid - process id of srcore 
  *
 **/
-static gint	gn_sr_pid;
+static gint	gn_srcore_pid;
 extern gint 	bm_pid;
 /**
  *
@@ -323,7 +323,7 @@ gn_child_exited (gint signo)
 {
     if (signo == SIGCHLD)
     {
-        if (waitpid (gn_sr_pid, &gn_srcore_status, WNOHANG) == gn_sr_pid)
+        if (waitpid (gn_srcore_pid, &gn_srcore_status, WNOHANG) == gn_srcore_pid)
 	{
 	    if (WIFEXITED (gn_srcore_status) == 0)
 	    {
@@ -354,7 +354,7 @@ gn_run_srcore (void)
 	gchar *args[] = {"../srcore/srcore",NULL};
 	if (!g_spawn_async ( ".", args , NULL, 
 			    G_SPAWN_DO_NOT_REAP_CHILD,
-			    NULL, NULL, &gn_sr_pid, NULL))
+			    NULL, NULL, &gn_srcore_pid, NULL))
 	{
 	    sru_message (_("No srcore binary file found [errno: %i]."),errno);
 	    return FALSE;
@@ -368,7 +368,7 @@ gn_run_srcore (void)
 	gchar *args[] = {"./srcore",NULL};
 	if (!g_spawn_async ( ".", args , NULL, 
 			G_SPAWN_DO_NOT_REAP_CHILD,
-			NULL, NULL, &gn_sr_pid, NULL))
+			NULL, NULL, &gn_srcore_pid, NULL))
 	{
 	    sru_message (_("No srcore binary file found [errno: :%i]"),errno);
 	    return FALSE;
@@ -379,7 +379,7 @@ gn_run_srcore (void)
 	gchar *args[] = {"srcore",NULL};
 	if (!g_spawn_async ( ".", args, NULL, 
 			    G_SPAWN_DO_NOT_REAP_CHILD | G_SPAWN_SEARCH_PATH,
-			    NULL, NULL, &gn_sr_pid, NULL))
+			    NULL, NULL, &gn_srcore_pid, NULL))
 	{
 	    sru_message (_("No srcore binary file found [errno: :%i]"),errno);
 	    return FALSE;
@@ -474,7 +474,7 @@ gn_destroy_instance (void)
 gboolean 
 gn_child_process_wait (void)
 {    
-    if (waitpid (gn_sr_pid, &gn_srcore_status, WNOHANG) == gn_sr_pid)
+    if (waitpid (gn_srcore_pid, &gn_srcore_status, WNOHANG) == gn_srcore_pid)
     {
 #ifdef __WAIT_DEBUG__
 	    if (WIFEXITED (gn_srcore_status)  != 0)
@@ -483,13 +483,20 @@ gn_child_process_wait (void)
 	    if (WIFSIGNALED(gn_srcore_status) != 0)
 		    sru_message ("Signaled: %d", WTERMSIG(gn_srcore_status));
 #endif
+	gn_srcore_pid = 0;
     }
+    
     /* Emit terminate signal to BrlMonitor that it to be sure it is exited */
     if (bm_pid != 0)
     {
-	if (kill (bm_pid, SIGTERM) == -1)
-	    sru_message (N_("Brlmonitor is not active"));
+	kill (bm_pid, SIGTERM);
     }
 	
+    /* Emit terminate signal to SRCore that it to be sure it is exited */
+    if (gn_srcore_pid != 0)
+    {
+	kill (gn_srcore_pid, SIGTERM);
+    }
+    
     return TRUE;    
 }
