@@ -41,7 +41,7 @@ gnopiconf_gconf_client_init (void)
     if (gnopernicus_client == NULL) 
     {
 	sru_warning (_("gnopernicus:Failed to init GConf client:\n"));
-	sru_warning (_("Recomanded to delete ~/.gconf and ~/.gconfd directories"));
+	sru_warning (_("Recommended to delete ~/.gconf and ~/.gconfd directories"));
 	return FALSE;
     }
     
@@ -61,7 +61,7 @@ gnopiconf_client_add_dir (const gchar *path)
     if (error != NULL)
     {
 	sru_warning (_("gnopiconf:Failed to add directory:%s\n"),path);
-	sru_warning (_("Recomanded to delete ~/.gconf and ~/.gconfd directories"));
+	sru_warning (_("Recommended to delete ~/.gconf and ~/.gconfd directories"));
 	g_error_free (error);
 	error = NULL;
 	return FALSE;
@@ -168,7 +168,7 @@ gnopiconf_set_int (gint val,
     if (error != NULL)
     {
 	sru_warning (_("gnopernicus:Failed to set value:%d\n"), val);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	g_error_free (error);
 	error = NULL;
     }
@@ -214,7 +214,7 @@ gnopiconf_set_string (const gchar *val,
     if (error != NULL)
     {
 	sru_warning (_("gnopernicus:Failed to set value:%s\n"), val);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	g_error_free (error);
 	error = NULL;
     }
@@ -256,7 +256,7 @@ gnopiconf_set_bool (gboolean val,
     if (error != NULL)
     {
 	sru_warning (_("gnopernicus:Failed to set value:%d\n"), val);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	g_error_free (error);
 	error = NULL;
     }
@@ -311,7 +311,7 @@ gnopiconf_get_int_with_default (const gchar *key,
         else
 	{
     	    sru_warning (_("gnopernicus:Invalid type of key %s\n"), key);
-	    sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	    if (!gnopiconf_set_int (ret_val, key))
 	        sru_warning (_("gnopernicus:Failed to set value %d\n"), ret_val);
 	}
@@ -325,7 +325,7 @@ gnopiconf_get_int_with_default (const gchar *key,
 	if (error != NULL)
 	{
 	    sru_warning (_("gnopernicus:Failed to get value %s\n"), key);
-	    sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	}
 	    
 	if (!gnopiconf_set_int (default_value, key))
@@ -375,7 +375,7 @@ gnopiconf_get_string_with_default (const gchar *key,
 	if (error != NULL)
 	{
 	    sru_warning (_("gnopernicus:Failed return string value %s\n"), key);
-	    sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	    g_error_free (error);
 	    error = NULL;
 	}
@@ -390,7 +390,7 @@ gnopiconf_get_string_with_default (const gchar *key,
 	if (error != NULL)
 	{
 	    sru_warning(_("gnopernicus:Failed to get value %s\n"), key);
-	    sru_warning(_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning(_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	    g_error_free (error);
 	    error = NULL;
 		
@@ -447,7 +447,7 @@ gnopiconf_get_bool_with_default (const gchar* key,
         else
 	{
     	    sru_warning (_("gnopernicus:Invalid type of key %s\n"), key);
-	    sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	    if (!gnopiconf_set_bool (retval, key))
 	        sru_warning (_("gnopernicus:Failed to set value %d\n"), retval);
 	}
@@ -460,7 +460,7 @@ gnopiconf_get_bool_with_default (const gchar* key,
 	if (error != NULL)
 	{
 	    sru_warning (_("gnopernicus:Failed to get value %s\n"), key);
-	    sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	}
 	    
 	if (!gnopiconf_set_bool (default_value, key))
@@ -510,7 +510,7 @@ gnopiconf_set_list (GSList *list,
     if (error != NULL)
     {
 	sru_warning (_("gnopernicus:Failed to set list with type %d\n"), list_type);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	g_error_free (error);
 	error = NULL;
     }
@@ -584,7 +584,7 @@ gnopiconf_get_list_with_default (const gchar* key,
         else
     	{
     	    sru_warning (_("cmdmapconf:Invalid type of key %s\n"), key);
-	    sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	    if (!gnopiconf_set_list (retval, *type, key))
 		    sru_warning (_("cmdmapconf:Failed to set value\n"));
 	}
@@ -597,7 +597,7 @@ gnopiconf_get_list_with_default (const gchar* key,
 	if (error != NULL)
 	{
 	    sru_warning (_("cmdmapconf:Failed to get value %s\n"), key);
-	    sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	    sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
 	}
 	    
         return NULL;
@@ -679,7 +679,7 @@ gnopiconf_get_all_entries (const gchar *path)
     if (error)
     {
         sru_warning (_("presentation:Failed to load items from directory:\n"));
-        sru_warning (_("Recomanded to delete ~/.gconf and ~/.gconfd directories"));
+        sru_warning (_("Recommended to delete ~/.gconf and ~/.gconfd directories"));
         g_error_free (error);
         error = NULL;
 	return NULL;
