@@ -76,7 +76,7 @@ spconf_gconf_client_init (void)
     if (error != NULL)
     {
         sru_warning (_("spconf:Failed to add notify:\n"));
-        sru_warning (_("Recomanded to delete ~/.gconf and ~/.gconfd directories"));
+        sru_warning (_("Recommended to delete ~/.gconf and ~/.gconfd directories"));
         g_error_free (error);
         error = NULL;
         return FALSE;
@@ -340,7 +340,7 @@ spconf_count_set (const gchar *count)
     if (!gnopiconf_set_string (count, CONFIG_PATH SPEECH_SETTING_KEY_PATH SPEECH_COUNT))
     {
 	sru_warning (_("spconf:Failed to set Count:%s\n"),count);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
     }
 }
 
@@ -350,7 +350,7 @@ spconf_punctuation_set (const gchar *punctuation)
     if (!gnopiconf_set_string (punctuation, CONFIG_PATH SPEECH_SETTING_KEY_PATH SPEECH_PUNCTUATION))
     {
 	sru_warning (_("spconf:Failed to set Punctuation:%s\n"),punctuation);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
     }
 }
 
@@ -360,7 +360,7 @@ spconf_text_echo_set (const gchar *text_echo)
     if (!gnopiconf_set_string (text_echo, CONFIG_PATH SPEECH_SETTING_KEY_PATH SPEECH_TEXT_ECHO))
     {
 	sru_warning (_("spconf:Failed to set text echo value:%s\n"),text_echo);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
     }
 }
 
@@ -370,7 +370,7 @@ spconf_modifiers_set (const gchar *modifiers)
     if (!gnopiconf_set_string (modifiers, CONFIG_PATH SPEECH_SETTING_KEY_PATH SPEECH_MODIFIERS))
     {
 	sru_warning (_("spconf:Failed to set modifiers value:%s\n"),modifiers);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
     }
 }
 
@@ -380,7 +380,7 @@ spconf_cursors_set (const gchar *cursors)
     if (!gnopiconf_set_string (cursors, CONFIG_PATH SPEECH_SETTING_KEY_PATH SPEECH_CURSORS))
     {
 	sru_warning (_("spconf:Failed to set cursors value:%s\n"),cursors);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
     }
 }
 
@@ -390,7 +390,7 @@ spconf_spaces_set (const gchar *spaces)
     if (!gnopiconf_set_string (spaces, CONFIG_PATH SPEECH_SETTING_KEY_PATH SPEECH_SPACES))
     {
 	sru_warning (_("spconf:Failed to set spaces value:%s\n"),spaces);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
     }
 }
 
@@ -400,7 +400,7 @@ spconf_dictionary_set (const gchar *dictionary)
     if (!gnopiconf_set_string (dictionary, CONFIG_PATH SPEECH_SETTING_KEY_PATH SPEECH_DICTIONARY_ACTIVE))
     {
 	sru_warning (_("spconf:Failed to set dictionary value:%s\n"),dictionary);
-	sru_warning (_("Recomanded to delete ~/.gconf/apps/gnopernicus directories"));
+	sru_warning (_("Recommended to delete ~/.gconf/apps/gnopernicus directories"));
     }
 }
 
