@@ -143,22 +143,39 @@ srl_log_at_spi (const AccessibleEvent *event)
 static void
 srl_log_gnopernicus (SREvent *event)
 {
-    SRObject *obj;
-    gchar *name, *role, *type;
+    SREventType ev_type;
+    
     if (!(srl_log_flags & SRL_LOG_GNOPERNICUS))
 	return;
 
-    sre_get_event_data (event, (void**)&obj);
-    sro_get_name (obj, &name, SR_INDEX_CONTAINER);
-    sro_get_role_name (obj, &role, SR_INDEX_CONTAINER);
-    sro_get_reason (obj, &type);
-    fprintf (stderr, "\nGN:%xp--\"%s\" "
+    sre_add_reference (event);
+    sre_get_type (event, &ev_type);
+    if (ev_type == SR_EVENT_MOUSE)
+    {
+	SRPoint *point;
+
+	sre_get_event_data (event, (void**)&point);
+	fprintf (stderr, "\nGN:%xp--\"mouse:move\" "
+			"at %d, %d", (unsigned int)event, point->x, point->y);
+    }
+    else
+    {
+	SRObject *obj;
+	gchar *name, *role, *type;
+    
+	sre_get_event_data (event, (void**)&obj);
+	sro_get_name (obj, &name, SR_INDEX_CONTAINER);
+	sro_get_role_name (obj, &role, SR_INDEX_CONTAINER);
+	sro_get_reason (obj, &type);
+	fprintf (stderr, "\nGN:%xp--\"%s\" "
 			"for %xp \"%s\" role \"%s\" ", 
-		(unsigned int)event, type ? type : "",
-		(unsigned int)obj, name ? name : "", role ? role : "");
-    SR_freeString (name);
-    SR_freeString (role);
-    SR_freeString (type);
+		    (unsigned int)event, type ? type : "",
+		    (unsigned int)obj, name ? name : "", role ? role : "");
+	SR_freeString (name);
+	SR_freeString (role);
+	SR_freeString (type);
+    }
+    sre_release_reference (event);
 }
 
 static void
