@@ -451,6 +451,10 @@ gboolean sro_image_get_location		(SRObject *obj,
 
 gboolean sro_text_get_caret_offset		(SRObject *obj,
 						    SRLong *line_offset, SRLong index);
+gboolean sro_text_get_caret_location		(SRObject *obj,
+						    SRCoordinateType type ,
+						    SRRectangle *location, 
+						    SRLong index);
 gboolean sro_text_set_caret_offset		(SRObject *obj,
 						    SRLong line_offset, SRLong index);
 gboolean sro_text_get_text_from_caret	   	(SRObject *obj, 
